@@ -36,7 +36,6 @@ class EventStreamBase(object):
     state_separator = "_"
     relation_type_separator = "-"
 
-    kafka_boot_time = 15
     bootstrap_servers = ['kafka:9092']
     group_id = 'worker'
     consumer_timeout_ms = 5000
@@ -68,6 +67,7 @@ class EventStreamBase(object):
         self.counter = counter_in
         self.log = self.log + str(self.id) + ": "
         self.bootstrap_servers = [os.environ.get('KAFKA_BOOTRSTRAP_SERVER', 'kafka:9092')]
+        self.setup_logging()
 
     def build_topic_list(self):
         """build a list of topics from the configs
@@ -83,7 +83,7 @@ class EventStreamBase(object):
                     result.append(self.build_topic_name(c_state, c_o_topic))
 
         self.topics = result
-        logging.warning("%s current topics for events: %s" % (self.log, self.topics))
+        logging.debug("%s current topics for events: %s" % (self.log, self.topics))
         return result
 
     def build_topic_name(self, state, relation_type=''):
@@ -142,7 +142,7 @@ class EventStreamBase(object):
         logging.warning(self.log + "Unable to resolve event, topic_name %s not found" % topic_name)
         return False
 
+    @staticmethod
+    def setup_logging():
+        logging.basicConfig(format="%(asctime)s: %(message)s", level=logging.WARNING, datefmt="%H:%M:%S")
 
-if __name__ == '__main__':
-    e = EventStreamBase(1)
-    print(e.build_topic_list())
